Learn R Programming

iRoCoDe (version 1.0.1)

get_treat: Generates number of treatments in a Design

Description

The get_treat function finds the number of treaments in a given design.

Usage

get_treat(design)

Arguments

design

A design in matrix format

Value

A list of treatments in a design.

Details

This function reads a design (D) in matrix format and finds the number of treatments (v) in the given design where rows are treated as blocks.