Learn R Programming

iRoCoDe (version 1.0.1)

rmv_list: Removes a item from a list

Description

The rmv_list function removes the specified item from the given list.

Usage

rmv_list(list, val)

Arguments

list

A list of values

val

A specific value

Value

It returns a list.

Details

This function reads a list of values and removes the specified value from that list.