Learn R Programming

iRoCoDe (version 1.0.1)

row_unique: Checks uniqness of elements in the rows of a matrix

Description

The row_unique function checks whether each row contains unique treatments.

Usage

row_unique(a_matrix, treatments, rows, cols)

Arguments

a_matrix

An 'a_matrix' of the first design (D1)

treatments

The treatments of the second design (D2)

rows

Number of rows in the given 'a_matrix'

cols

Number of columns in the given 'a_matrix'

Value

It returns boolean value (either True or False).

Details

This function reads an 'a_matrix' (A) generated from two designs (D1 and D2) and checks whether each row contains all the treatments from D2 exactly once.