powered by
The get_treat function finds the number of treaments in a given design.
get_treat(design)
A design in matrix format
A list of treatments in a design.
This function reads a design (D) in matrix format and finds the number of treatments (v) in the given design where rows are treated as blocks.