powered by
The rmv_list function removes the specified item from the given list.
rmv_list(list, val)
A list of values
A specific value
It returns a list.
This function reads a list of values and removes the specified value from that list.