The row_unique function checks whether each row contains unique treatments.
row_unique(a_matrix, treatments, rows, cols)An 'a_matrix' of the first design (D1)
The treatments of the second design (D2)
Number of rows in the given 'a_matrix'
Number of columns in the given 'a_matrix'
It returns boolean value (either True or False).
This function reads an 'a_matrix' (A) generated from two designs (D1 and D2) and checks whether each row contains all the treatments from D2 exactly once.